@@ -49,10 +49,10 @@ print("Creating handle client")
 pid_service = PidService.from_credentials("pyhandle_creds.json")
 
 print("Getting data from the directory")
-biobanks = session.get_uploadable_data(table)
+biobanks = session.get(table, uploadable=True)
 
 print("Registering PIDs")
-url_prefix = session.url + "#/biobank/"
+url_prefix = pid_service.base_url + "#/biobank/"
 for biobank in biobanks:
     if "pid" in biobank:
         continue
@@ -63,6 +63,6 @@ for biobank in biobanks:
     print(f"Generated {pid} for {biobank['id']}")
 
 print("Uploading to directory")
-session.update_batched(table, biobanks)
+session.update_all(table, biobanks)
 
 print("All done!")
