@@ -4,19 +4,20 @@ from collections import OrderedDict
 from copy import deepcopy
 from dataclasses import dataclass, field
 from enum import Enum
-from typing import Dict, List, Optional, Set
+from typing import Dict, List, Set
 
 from molgenis.bbmri_eric.utils import to_ordered_dict
 
 
 class TableType(Enum):
-    """Enum representing the five tables each national node has."""
+    """Enum representing the six tables each national node has."""
 
     PERSONS = "persons"
-    NETWORKS = "networks"
     ALSO_KNOWN = "also_known_in"
+    NETWORKS = "networks"
     BIOBANKS = "biobanks"
     COLLECTIONS = "collections"
+    FACTS = "facts"
 
     @classmethod
     def get_import_order(cls) -> List["TableType"]:
@@ -121,6 +122,26 @@ class OntologyTable(BaseTable):
     """
 
     parent_attr: str
+    matching_attrs: List[str] | None = None
+
+    def get_matching_ontologies(self, ontologies: List[str]) -> Set[str]:
+        """
+        Will add matching ontologies with the specified level(s) of confidence to the
+        list of ontologies
+
+        :param ontologies: a list with the current ontologies
+        :return: a list with the current ontologies extended with matching ontologies,
+        if available.
+        """
+        matching_ontologies = []
+        for attr in self.matching_attrs:
+            for ontology in ontologies:
+                try:
+                    matching_ontologies.extend(self.rows_by_id[ontology][attr])
+                except KeyError:
+                    pass
+
+        return set(matching_ontologies)
 
     def is_descendant_of_any(self, descendant_id: str, ancestor_ids: Set[str]) -> bool:
         """
@@ -141,11 +162,20 @@ class OntologyTable(BaseTable):
             current = self.rows_by_id[current[self.parent_attr]]
 
     @staticmethod
-    def of(meta: TableMeta, rows: List[dict], parent_attr: str) -> "OntologyTable":
+    def of(
+        meta: TableMeta,
+        rows: List[dict],
+        parent_attr: str,
+        matching_attrs: List[str] | None = None,
+    ) -> "OntologyTable":
         """Factory method that takes a list of rows instead of an OrderedDict of
         ids/rows."""
+        matching_attrs = matching_attrs if matching_attrs else []
         return OntologyTable(
-            rows_by_id=to_ordered_dict(rows), meta=meta, parent_attr=parent_attr
+            rows_by_id=to_ordered_dict(rows),
+            meta=meta,
+            parent_attr=parent_attr,
+            matching_attrs=matching_attrs,
         )
 
 
@@ -154,7 +184,8 @@ class Node:
     """Represents a single national node in the BBMRI ERIC directory."""
 
     code: str
-    description: Optional[str]
+    description: str | None = None
+    date_end: str | None = None
 
     _classifiers = {
         TableType.PERSONS: "contactID",
@@ -162,6 +193,7 @@ class Node:
         TableType.ALSO_KNOWN: "akiID",
         TableType.BIOBANKS: "ID",
         TableType.COLLECTIONS: "ID",
+        TableType.FACTS: "factID",
     }
 
     def get_staging_id(self, table_type: TableType) -> str:
@@ -199,7 +231,7 @@ class Node:
 
     @staticmethod
     def of(code: str):
-        return Node(code, None)
+        return Node(code, None, None)
 
     def __eq__(self, other: object) -> bool:
         if isinstance(other, Node):
@@ -214,7 +246,7 @@ class Node:
 class ExternalServerNode(Node):
     """Represents a node that has an external server on which its data is hosted."""
 
-    url: str
+    url: str | None = None
 
 
 class Source(Enum):
@@ -226,8 +258,8 @@ class Source(Enum):
 
 @dataclass
 class EricData(ABC):
-    """Abstract base class for containers storing rows from the five ERIC tables:
-    persons, networks, also_known_in, biobanks and collections."""
+    """Abstract base class for containers storing rows from the six ERIC tables:
+    persons, networks, also_known_in, biobanks, collections and facts."""
 
     source: Source
     persons: Table
@@ -235,6 +267,7 @@ class EricData(ABC):
     networks: Table
     biobanks: Table
     collections: Table
+    facts: Table
     table_by_type: Dict[TableType, Table] = field(init=False)
 
     def __post_init__(self):
@@ -244,6 +277,7 @@ class EricData(ABC):
             TableType.ALSO_KNOWN: self.also_known_in,
             TableType.BIOBANKS: self.biobanks,
             TableType.COLLECTIONS: self.collections,
+            TableType.FACTS: self.facts,
         }
 
     @property
@@ -254,12 +288,13 @@ class EricData(ABC):
             self.also_known_in,
             self.biobanks,
             self.collections,
+            self.facts,
         ]
 
 
 @dataclass
 class NodeData(EricData):
-    """Container object storing the five tables of a single node."""
+    """Container object storing the six tables of a single node."""
 
     node: Node
 
@@ -288,7 +323,7 @@ class NodeData(EricData):
 
 
 class MixedData(EricData):
-    """Container object storing the five tables with mixed origins, for example from
+    """Container object storing the six tables with mixed origins, for example from
     the combined tables or from multiple staging areas."""
 
     @staticmethod
@@ -301,6 +336,7 @@ class MixedData(EricData):
         self.also_known_in.rows_by_id.update(other_data.also_known_in.rows_by_id)
         self.biobanks.rows_by_id.update(other_data.biobanks.rows_by_id)
         self.collections.rows_by_id.update(other_data.collections.rows_by_id)
+        self.facts.rows_by_id.update(other_data.facts.rows_by_id)
 
     def remove_node_rows(self, node: Node):
         for table in self.import_order:
@@ -317,6 +353,7 @@ class MixedData(EricData):
             also_known_in=Table.of_empty(TableType.ALSO_KNOWN, self.also_known_in.meta),
             biobanks=Table.of_empty(TableType.BIOBANKS, self.biobanks.meta),
             collections=Table.of_empty(TableType.COLLECTIONS, self.collections.meta),
+            facts=Table.of_empty(TableType.FACTS, self.facts.meta),
         )
 
 
