@@ -23,7 +23,7 @@ def test_stager():
     stager._import_node = MagicMock(name="_import_node")
     stager._get_source_data = MagicMock(name="_get_mock_data")
     stager._get_source_data.return_value = source_data
-    node = ExternalServerNode("NL", "NL", "url")
+    node = ExternalServerNode("NL", "NL", url="url")
 
     stager.stage(node)
 
@@ -34,7 +34,7 @@ def test_stager():
 
 def test_get_source_data(external_server_init):
     node_data = MagicMock()
-    node = ExternalServerNode("NL", "Netherlands", "url.nl")
+    node = ExternalServerNode("NL", "Netherlands", url="url.nl")
     source_session_mock_instance = external_server_init.return_value
     source_session_mock_instance.get_node_data.return_value = node_data
 
@@ -45,7 +45,7 @@ def test_get_source_data(external_server_init):
 
 
 def test_check_tables(external_server_init):
-    node = ExternalServerNode("NL", "Netherlands", "url.nl")
+    node = ExternalServerNode("NL", "Netherlands", url="url.nl")
     session = external_server_init.return_value
     session.get.return_value = []
     session.node = node
@@ -55,27 +55,29 @@ def test_check_tables(external_server_init):
 
     external_server_init.assert_called_with(node=node)
 
-    assert session.get.call_count == 5
+    assert session.get.call_count == 6
 
     assert warnings[0] == EricWarning("Node NL has no persons table")
-    assert warnings[1] == EricWarning("Node NL has no networks table")
-    assert warnings[2] == EricWarning("Node NL has no also_known_in table")
+    assert warnings[1] == EricWarning("Node NL has no also_known_in table")
+    assert warnings[2] == EricWarning("Node NL has no networks table")
     assert warnings[3] == EricWarning("Node NL has no biobanks table")
     assert warnings[4] == EricWarning("Node NL has no collections table")
+    assert warnings[5] == EricWarning("Node NL has no facts table")
 
 
 def test_clear_staging_area():
     session = EricSession("url")
     session.delete = MagicMock(name="delete")
-    node = ExternalServerNode("NL", "Netherlands", "url.nl")
+    node = ExternalServerNode("NL", "Netherlands", url="url.nl")
 
     Stager(session, Printer())._clear_staging_area(node)
 
     assert session.delete.mock_calls == [
+        mock.call("eu_bbmri_eric_NL_facts"),
         mock.call("eu_bbmri_eric_NL_collections"),
         mock.call("eu_bbmri_eric_NL_biobanks"),
-        mock.call("eu_bbmri_eric_NL_also_known_in"),
         mock.call("eu_bbmri_eric_NL_networks"),
+        mock.call("eu_bbmri_eric_NL_also_known_in"),
         mock.call("eu_bbmri_eric_NL_persons"),
     ]
 
