@@ -64,6 +64,10 @@ def test_validate_id(node_data):
             message="bbmri-eric:ID:BE_invalid_node_code:collectionID in entity: "
             "eu_bbmri_eric_NL_collections does not start with bbmri-eric:ID:NL_"
         ),
+        EricWarning(
+            message="bbmri-eric:NL_invalid:factsID in entity: "
+            "eu_bbmri_eric_NL_facts does not start with bbmri-eric:factID:NL_"
+        ),
         EricWarning(
             message="bbmri-eric:networkID:NL_valid:networkID-2 references invalid id: "
             "bbmri-eric:ID:NL_invalid_person_classifier"
@@ -111,17 +115,13 @@ def test_validate_id(node_data):
     "collection,expected",
     [
         (dict(), []),
-        ({"id": "0", "age_low": 0, "age_unit": ["YEAR"]}, []),
-        (
-            {"id": "1", "age_low": 0, "age_unit": ["YEAR", "MONTH"]},
-            [EricWarning("Collection 1 has more than one age_unit: ['YEAR', 'MONTH']")],
-        ),
+        ({"id": "0", "age_low": 0, "age_unit": "YEAR"}, []),
         (
             {"id": "2", "age_low": 5},
             [EricWarning("Collection 2 has age_low/age_high without age_unit")],
         ),
         (
-            {"id": "3", "age_low": 0, "age_high": 0, "age_unit": ["YEAR"]},
+            {"id": "3", "age_low": 0, "age_high": 0, "age_unit": "YEAR"},
             [
                 EricWarning(
                     "Collection 3 has invalid ages: age_low = 0 and age_high = " "0"
